@@ -1,6 +1,6 @@
 """ Widgets for core HTML 5 controls
 """
-from ._version import __version__  # noqa
+from ._version import __version__, module_name
 from .widget_color import AlphaColor, AlphaColorPicker, EmptyAlphaColor
 from .widget_file import File, FileBox, JSONFile, TextFile
 from .widget_fullscreen import Fullscreen
@@ -16,3 +16,7 @@ __all__ = [
     "JSONFile",
     "TextFile",
 ]
+
+
+def _jupyter_labextension_paths():
+    return [{"src": "labextension", "dest": module_name}]
